#
# PySNMP MIB module FRNETSERV-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/FRNETSERV-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:13:33 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ValueSizeConstraint, ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ValueSizeConstraint", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection")
( InterfaceIndex, ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex", "ifIndex")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, MibIdentifier, ObjectIdentity, Gauge32, IpAddress, TimeTicks, ModuleIdentity, NotificationType, Integer32, iso, Counter64, Bits, transmission, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32", "MibIdentifier", "ObjectIdentity", "Gauge32", "IpAddress", "TimeTicks", "ModuleIdentity", "NotificationType", "Integer32", "iso", "Counter64", "Bits", "transmission", "Counter32")
( DisplayString, TimeStamp, TextualConvention, RowStatus, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TimeStamp", "TextualConvention", "RowStatus")
frnetservMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 44)).setRevisions(("2000-09-28 00:00", "1993-11-16 12:00",))
if mibBuilder.loadTexts: frnetservMIB.setLastUpdated('200009280000Z')
if mibBuilder.loadTexts: frnetservMIB.setOrganization('IETF Frame Relay Service MIB Working Group')
if mibBuilder.loadTexts: frnetservMIB.setContactInfo('WG Charter:\n                   http://www.ietf.org/html.charters/frnetmib-charter\n                 WG-email:\n                   frnetmib@sunroof.eng.sun.com\n\n                 Subscribe:\n                   frnetmib-request@sunroof.eng.sun.com\n                 Email Archive:\n                   ftp://ftp.ietf.org/ietf-mail-archive/frnetmib\n\n                 Chair:      Andy Malis\n                             Vivace Networks, Inc.\n                 Email:      Andy.Malis@vivacenetworks.com\n\n                 WG editor:  Kenneth Rehbehn\n                             Megisto Systems, Inc.\n                 Email:      krehbehn@megisto.com\n\n                 Co-author:  David Fowler\n                             Syndesis Limited,\n                 EMail:      fowler@syndesis.com')
if mibBuilder.loadTexts: frnetservMIB.setDescription('The MIB module to describe generic objects for\n                  Frame Relay Network Service.')
frnetservObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 44, 1))
frnetservTraps = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 44, 2))
frnetservTrapsPrefix = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 44, 2, 0))
frLportTable = MibTable((1, 3, 6, 1, 2, 1, 10, 44, 1, 1), )
if mibBuilder.loadTexts: frLportTable.setDescription('The Frame Relay Logical Port Information table is\n                    an interface-specific addendum to the generic\n                    ifTable of the Interface MIB.')
frLportEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 44, 1, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: frLportEntry.setDescription('An entry in the Frame Relay Logical Port\n                    Information table.')
frLportNumPlan = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 1, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("other", 1), ("e164", 2), ("x121", 3), ("none", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frLportNumPlan.setDescription('The value of this object identifies the network\n                    address numbering plan for this UNI/NNI logical\n                    port. The network address is the object\n                    ifPhysAddress. The value none(4) implies that\n                    there is no ifPhysAddress.  The FRS agent will\n                    return an octet string of zero length for\n                    ifPhysAddress.  The value other(1) means that an\n                    address has been assigned to this interface, but\n                    the numbering plan is not enumerated here.')
frLportContact = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 1, 1, 2), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frLportContact.setDescription('The value of this object identifies the network\n                    contact for this UNI/NNI logical port.')
frLportLocation = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 1, 1, 3), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frLportLocation.setDescription('The value of this object identifies the frame\n                    relay network location for this UNI/NNI logical\n                    port.')
frLportType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("uni", 1), ("nni", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frLportType.setDescription('The value of this object identifies the type of\n                    network interface for this logical port.')
frLportAddrDLCILen = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 1, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("twoOctets10Bits", 1), ("threeOctets10Bits", 2), ("threeOctets16Bits", 3), ("fourOctets17Bits", 4), ("fourOctets23Bits", 5),))).setUnits('Octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: frLportAddrDLCILen.setDescription('The value of this object identifies the Q.922\n                    Address field length and DLCI length for this\n                    UNI/NNI logical port.')
frLportVCSigProtocol = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 1, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("none", 1), ("lmi", 2), ("ansiT1617D", 3), ("ansiT1617B", 4), ("ccittQ933A", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frLportVCSigProtocol.setDescription('The value of this object identifies the Local\n                    In-Channel Signaling Protocol that is used for\n                    this frame relay UNI/NNI logical port.\n\n                    none(1):        Interface does not use a PVC\n                                    signaling protocol\n\n                    lmi(2):         Interface operates the Stratacom/\n                                    Nortel/DEC Local Management\n                                    Interface Specification protocol\n\n                    ansiT1617D(3):  Interface operates the ANSI T1.617\n                                    Annex D PVC status protocol\n\n                      ansiT1617B(4):  Interface operates the ANSI\nT1.617\n                                      Annex B procedures\n\n                      ccittQ933A(5):  Interface operates the ITU Q.933\n                                      Annex A PVC status protocol')
frLportVCSigPointer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 1, 1, 7), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frLportVCSigPointer.setDescription('The value of this object is used as a pointer to\n                    the table that contains the Local In-Channel\n                    Signaling Protocol parameters and errors for this\n                    UNI/NNI logical port.\n\n                    This object has been deprecated to reflect the\n                    fact that the local in-channel signaling\n                    parameters are accessed from a single table\n                    (frMgtVCSigTable) that includes parameters for all\n                    possible signaling protocols.  Early design\n                    anticipated multiple tables, one for each\n                    signaling protocol.')
frLportDLCIIndexValue = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 1, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(16,4194303))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frLportDLCIIndexValue.setDescription('This object contains a hint to be used for\n                    frPVCEndptDLCIIndex when creating entries in the\n                    frPVCEndptTable.  The SYNTAX of this object\n                    matches the SYNTAX of the frPVCEndptDLCIIndex - an\n                    object that is restricted to legal Q.922 DLCI\n                    values for the size of the address field.\n\n                    The value 0 indicates that no unassigned entries\n                    are available.\n\n                    To obtain the frPVCEndptDLCIIndex value for a new\n                    entry, the manager issues a management protocol\n                    retrieval operation to obtain the current value of\n\n                    this object.  After each retrieval, the agent must\n                    modify the value to the next unassigned index to\n                    prevent assignment of the same value to multiple\n                    management systems.\n\n                    A management system should repeat the read to\n                    obtain a new value should an attempt to create the\n                    new row using the previously returned hint fail.')
frLportTypeAdmin = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 1, 1, 9), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("uni", 1), ("nni", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: frLportTypeAdmin.setDescription('The value of this object desired identifies the\n                    type of network interface for this logical port.')
frLportVCSigProtocolAdmin = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 1, 1, 10), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("none", 1), ("lmi", 2), ("ansiT1617D", 3), ("ansiT1617B", 4), ("ccittQ933A", 5),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: frLportVCSigProtocolAdmin.setDescription('The value of this object identifies the desired\n                    Local In-Channel Signaling Protocol that is used\n                    for this frame relay UNI/NNI logical port.  This\n                    value must be made the active protocol as soon as\n                    possible on the device.\n\n                    Refer to frLportVCSigProtocol for a description of\n                    each signaling protocol choices.')
frLportFragControl = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 1, 1, 11), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("on", 1), ("off", 2),)).clone('off')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: frLportFragControl.setDescription('This object controls the transmission and\n                    reception of fragmentation frames for this UNI or\n                    NNI interface.\n\n                    on(1)   Frames are fragmented using the interface\n                            fragmentation format\n                            Note:  The customer side of the interface\n                            must also be configured to fragment\n                            frames.\n\n                    off(2)  Frames are not fragmented using the\n                            interface fragmentation format.')
frLportFragSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 1, 1, 12), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,4096))).setUnits('Octets').setMaxAccess("readwrite")
if mibBuilder.loadTexts: frLportFragSize.setDescription('The value of this object is the size in octets of\n                    the maximum size of each fragment to be sent when\n                    fragmenting.  This object is only used by the\n                    fragmentation transmitter, and the two sides of\n                    the interface may differ.  The fragment size\n                    includes the octets for the frame relay header,\n                    the UI octet, the NLPID, the fragmentation header,\n                    and the fragment payload. If frLportFragControl is\n                    set to off, this value should be zero.')
frMgtVCSigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 44, 1, 2), )
if mibBuilder.loadTexts: frMgtVCSigTable.setDescription('The Frame Relay Management VC Signaling\n                    Parameters and Errors table.')
frMgtVCSigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: frMgtVCSigEntry.setDescription('An entry in the Frame Relay Management VC\n                    Signaling Parameters Errors table.')
frMgtVCSigProced = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("u2nnet", 1), ("bidirect", 2), ("u2nuser", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frMgtVCSigProced.setDescription('The value of this object identifies the local\n                    in-channel signaling procedural role that is used\n                    for this UNI/NNI logical port.  Bidirectional\n                    procedures implies that both user-side and\n                    network-side procedural roles are used.\n\n                    u2nnet(1)   Logical port operates user to network\n                                procedure in the role of the network\n                                side\n\n                    bidirect(2) Logical port operates the\n                                bidirectional procedure (both user\n                                and network side roles)\n\n                    u2nuser(3)  Logical port operates user to network\n                                procedure in the role of the user\n                                side')
frMgtVCSigUserN391 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,255)).clone(6)).setUnits('Polls').setMaxAccess("readonly")
if mibBuilder.loadTexts: frMgtVCSigUserN391.setDescription('The value of this object identifies the User-side\n                    N391 full status polling cycle value for this\n                    UNI/NNI logical port.  If the logical port is not\n                    performing user-side (bidirectional) procedures,\n                    then this object is not instantiated and an\n                    attempt to read will result in the noSuchInstance\n                    exception response.')
frMgtVCSigUserN392 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10)).clone(3)).setUnits('Events').setMaxAccess("readonly")
if mibBuilder.loadTexts: frMgtVCSigUserN392.setDescription('The value of this object identifies the User-side\n                    N392 error threshold value for this UNI/NNI\n                    logical port.  If the logical port is not\n                    performing user-side (bidirectional) procedures,\n                    then this object is not instantiated.')
frMgtVCSigUserN393 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10)).clone(4)).setUnits('Events').setMaxAccess("readonly")
if mibBuilder.loadTexts: frMgtVCSigUserN393.setDescription('The value of this object identifies the User-side\n                    N393 monitored events count value for this UNI/NNI\n                    logical port.  If the logical port is not\n                    performing user-side (bidirectional) procedures,\n                    then this object is not instantiated.')
frMgtVCSigUserT391 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(5,30)).clone(10)).setUnits('Seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: frMgtVCSigUserT391.setDescription('The value of this object identifies the User-side\n                    T391 link integrity verification polling timer\n                    value for this UNI/NNI logical port.  If the\n                    logical port is not performing user-side\n                    procedures, then this object is not instantiated.')
frMgtVCSigNetN392 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10)).clone(3)).setUnits('Events').setMaxAccess("readonly")
if mibBuilder.loadTexts: frMgtVCSigNetN392.setDescription('The value of this object identifies the Network-\n                    side N392 error threshold value (nN2 for LMI) for\n                    this UNI/NNI logical port.  If the logical port is\n                    not performing network-side procedures, then this\n                    object is not instantiated.')
frMgtVCSigNetN393 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10)).clone(4)).setUnits('Events').setMaxAccess("readonly")
if mibBuilder.loadTexts: frMgtVCSigNetN393.setDescription('The value of this object identifies the Network-\n                    side N393 monitored events count value (nN3 for\n                    LMI) for this UNI/NNI logical port.  If the\n                    logical port is not performing network-side\n                    procedures, then this object is not instantiated.')
frMgtVCSigNetT392 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(5,30)).clone(15)).setUnits('Seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: frMgtVCSigNetT392.setDescription('The value of this object identifies the Network-\n                    side T392 polling verification timer value (nT2\n                    for LMI)  for this UNI/NNI logical port.  If the\n                    logical port is not performing network-side\n                    procedures, then this object is not instantiated.')
frMgtVCSigNetnN4 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 9), Integer32().subtype(subtypeSpec=ValueRangeConstraint(5,5))).setUnits('Events').setMaxAccess("readonly")
if mibBuilder.loadTexts: frMgtVCSigNetnN4.setDescription('The value of this object identifies the Network-\n                    side nN4 maximum status enquires received value\n                    for this UNI/NNI logical port.  If the logical\n                    port is not performing network-side procedures or\n                    is not performing LMI procedures, then this object\n                    is not instantiated.\n\n                    This object applies only to LMI and always has a\n                    value of 5.')
frMgtVCSigNetnT3 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 10), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(5,5),ValueRangeConstraint(10,10),ValueRangeConstraint(15,15),ValueRangeConstraint(20,20),ValueRangeConstraint(25,25),ValueRangeConstraint(30,30),)).clone(20)).setUnits('Seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: frMgtVCSigNetnT3.setDescription('The value of this object identifies the Network-\n                    side nT3 timer (for nN4 status enquires received)\n                    value for this UNI/NNI logical port.  If the\n                    logical port is not performing network-side\n                    procedures or is not performing LMI procedures,\n                    then this object is not instantiated.\n\n                      This object applies only to LMI.')
frMgtVCSigUserLinkRelErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 11), Counter32()).setUnits('Errors').setMaxAccess("readonly")
if mibBuilder.loadTexts: frMgtVCSigUserLinkRelErrors.setDescription('The number of user-side local in-channel\n                    signaling link reliability errors (i.e., non-\n                    receipt of Status/Status Enquiry messages or\n                    invalid sequence numbers in a Link Integrity\n                    Verification Information Element) for this UNI/NNI\n                    logical port.  If the logical port is not\n\n                    performing user-side procedures, then this object\n                    is not instantiated.')
frMgtVCSigUserProtErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 12), Counter32()).setUnits('Errors').setMaxAccess("readonly")
if mibBuilder.loadTexts: frMgtVCSigUserProtErrors.setDescription('The number of user-side local in-channel\n                    signaling protocol errors (i.e., protocol\n                    discriminator, unnumbered information, message\n                    type, call reference, and mandatory information\n                    element errors) for this UNI/NNI logical port. If\n                    the logical port is not performing user-side\n                    procedures, then this object is not instantiated.')
frMgtVCSigUserChanInactive = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 13), Counter32()).setUnits('Events').setMaxAccess("readonly")
if mibBuilder.loadTexts: frMgtVCSigUserChanInactive.setDescription('The number of times the user-side channel was\n                    declared inactive (i.e., N392 errors in N393\n                    events) for this UNI/NNI logical port. If the\n                    logical port is not performing user-side\n                    procedures, then this object is not instantiated.')
frMgtVCSigNetLinkRelErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 14), Counter32()).setUnits('Errors').setMaxAccess("readonly")
if mibBuilder.loadTexts: frMgtVCSigNetLinkRelErrors.setDescription('The number of network-side local in-channel\n                    signaling link reliability errors (i.e., non-\n                    receipt of Status/Status Enquiry messages or\n                    invalid sequence numbers in a Link Integrity\n                    Verification Information Element) for this UNI/NNI\n                    logical port.')
frMgtVCSigNetProtErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 15), Counter32()).setUnits('Errors').setMaxAccess("readonly")
if mibBuilder.loadTexts: frMgtVCSigNetProtErrors.setDescription('The number of network-side local in-channel\n                    signaling protocol errors (i.e., protocol\n                    discriminator, message type, call reference, and\n                    mandatory information element errors) for this\n                    UNI/NNI logical port.')
frMgtVCSigNetChanInactive = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 16), Counter32()).setUnits('Events').setMaxAccess("readonly")
if mibBuilder.loadTexts: frMgtVCSigNetChanInactive.setDescription('The number of times the network-side channel was\n                    declared inactive (i.e., N392 errors in N393\n                    events) for this UNI/NNI logical port.')
frMgtVCSigProcedAdmin = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 17), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("u2nnet", 1), ("bidirect", 2), ("u2nuser", 3),)).clone('u2nnet')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: frMgtVCSigProcedAdmin.setDescription('The value of this object identifies the local\n                    in-channel signaling procedural role that is used\n                    for this UNI/NNI logical port.  Bidirectional\n                    procedures implies that both user-side and\n                    network-side procedural roles are used.\n\n                    u2nnet(1)   Logical port operates user to network\n                                procedure in the role of the network\n                                side\n\n                    bidirect(2) Logical port operates the\n                                bidirectional procedure (both user\n                                and network side roles)\n\n                    u2nuser(3)  Logical port operates user to network\n                                procedure in the role of the user\n                                side')
frMgtVCSigUserN391Admin = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 18), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,255))).setUnits('Polls').setMaxAccess("readwrite")
if mibBuilder.loadTexts: frMgtVCSigUserN391Admin.setDescription('The value of this object identifies the desired\n                    User-side N391 full status polling cycle value for\n                    this UNI/NNI logical port.  If the logical port is\n                    not performing user-side (bidirectional)\n                    procedures, then this object is not instantiated.')
frMgtVCSigUserN392Admin = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 19), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10))).setUnits('Events').setMaxAccess("readwrite")
if mibBuilder.loadTexts: frMgtVCSigUserN392Admin.setDescription('The value of this object identifies the desired\n                    User-side N392 error threshold value for this\n                    UNI/NNI logical port.  If the logical port is not\n                    performing user-side (bidirectional) procedures,\n                    then this object is not instantiated.')
frMgtVCSigUserN393Admin = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 20), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10))).setUnits('Events').setMaxAccess("readwrite")
if mibBuilder.loadTexts: frMgtVCSigUserN393Admin.setDescription('The value of this object identifies the desired\n                    User-side N393 monitored events count value for\n                    this UNI/NNI logical port.  If the logical port is\n                    not performing user-side (bidirectional)\n                    procedures, then this object is not instantiated.')
frMgtVCSigUserT391Admin = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 21), Integer32().subtype(subtypeSpec=ValueRangeConstraint(5,30))).setUnits('Seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: frMgtVCSigUserT391Admin.setDescription('The value of this object identifies the desired\n                    User-side T391 link integrity verification polling\n                    timer value for this UNI/NNI logical port.  If the\n                    logical port is not performing user-side\n                    procedures, then this object is not instantiated.')
frMgtVCSigNetN392Admin = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 22), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10))).setUnits('Events').setMaxAccess("readwrite")
if mibBuilder.loadTexts: frMgtVCSigNetN392Admin.setDescription('The value of this object identifies the desired\n                    Network-side N392 error threshold value (nN2 for\n                    LMI) for this UNI/NNI logical port.  If the\n                    logical port is not performing network-side\n                    procedures, then this object is not instantiated.')
frMgtVCSigNetN393Admin = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 23), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10))).setUnits('Events').setMaxAccess("readwrite")
if mibBuilder.loadTexts: frMgtVCSigNetN393Admin.setDescription('The value of this object identifies the desired\n                    Network-side N393 monitored events count value\n                    (nN3 for LMI) for this UNI/NNI logical port.  If\n                    the logical port is not performing network-side\n                    procedures, then this object is not instantiated.')
frMgtVCSigNetT392Admin = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 24), Integer32().subtype(subtypeSpec=ValueRangeConstraint(5,30))).setUnits('Seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: frMgtVCSigNetT392Admin.setDescription('The value of this object identifies the desired\n                    Network-side T392 polling verification timer value\n                    (nT2 for LMI)  for this UNI/NNI logical port. If\n                    the logical port is not performing network-side\n                    procedures, then this object is not instantiated.')
frMgtVCSigNetnT3Admin = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 2, 1, 25), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(5,5),ValueRangeConstraint(10,10),ValueRangeConstraint(15,15),ValueRangeConstraint(20,20),ValueRangeConstraint(25,25),ValueRangeConstraint(30,30),))).setUnits('Seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: frMgtVCSigNetnT3Admin.setDescription('The value of this object identifies the desired\n                    Network-side nT3 timer (for nN4 status enquires\n                    received) value for this UNI/NNI logical port. If\n                    the logical port is not performing network-side\n                    procedures or is not performing LMI procedures,\n                    then this object is not instantiated.  This object\n                    applies only to LMI.')
frPVCEndptTable = MibTable((1, 3, 6, 1, 2, 1, 10, 44, 1, 3), )
if mibBuilder.loadTexts: frPVCEndptTable.setDescription("The Frame Relay PVC End-Point table.  This table\n                    is used to model a PVC end-point.  This table\n                    contains the traffic parameters and statistics for\n                    a PVC end-point.\n\n                    This table is used to identify the traffic\n                    parameters for a bi-directional PVC segment end-\n\n                    point, and it also provides statistics for a PVC\n                    segment end-point.\n\n                    A PVC segment end-point is identified by a UNI/NNI\n                    logical port index value and DLCI index value.\n\n                    If the frame relay service provider allows the\n                    frame relay CNM subscriber to create, modify or\n                    delete PVCs using SNMP, then this table is used to\n                    identify and reserve the requested traffic\n                    parameters of each PVC segment end-point.  The\n                    Connection table is used to 'connect' the end-\n                    points together.  Not all implementations will\n                    support the capability of\n                    creating/modifying/deleting PVCs using SNMP as a\n                    feature of frame relay CNM service.\n\n                    Uni-directional PVCs are modeled with zero valued\n                    traffic parameters in one of the directions (In or\n                     Out direction) in this table.\n\n                    To create a PVC, the following procedures shall be\n                    followed:\n\n                    1)  Create the entries for the PVC segment\n                        endpoints in the frPVCEndptTable by specifying\n                        the traffic parameters for the bi-directional\n                        PVC segment endpoints. As shown in figure 2, a\n                        point-to-point PVC has two endpoints, thus two\n                        entries in this table.  Uni-directional PVCs\n                        are modeled with zero valued traffic\n                        parameters in one direction; all the `In'\n                        direction parameters for one frame relay PVC\n                        End-point or all the `Out' direction\n                        parameters for the other frame relay PVC\n                        Endpoint.\n\n                        In    _____________________________  Out\n                       >>>>>>|                             |>>>>>>>>\n                       ______|    Frame Relay Network      |________\n                        Out  |                             |  In\n                       <<<<<<|_____________________________|<<<<<<<<\n                     Frame Relay                         Frame Relay\n                         PVC                                 PVC\n                       Endpoint                            Endpoint\n\n                                Figure 2, PVC Terminology\n\n\n                    2)  Go to the Frame Relay Connection Group.")
frPVCEndptEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "FRNETSERV-MIB", "frPVCEndptDLCIIndex"))
if mibBuilder.loadTexts: frPVCEndptEntry.setDescription('An entry in the Frame Relay PVC Endpoint table.')
frPVCEndptDLCIIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(16,4194303)))
if mibBuilder.loadTexts: frPVCEndptDLCIIndex.setDescription('The value of this object is equal to the DLCI\n                    value for this PVC end-point.\n\n                    The values are restricted to the legal range for\n                    the size of address field supported by the logical\n                    port (frLportAddrDLCILen).')
frPVCEndptInMaxFrameSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,4096)).clone(1600)).setUnits('Octets').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frPVCEndptInMaxFrameSize.setDescription('The value of this object is the size in octets of\n                    the largest frame relay information field for this\n                    PVC end-point in the ingress direction (into the\n                    frame relay network).  The value of\n                    frPVCEndptInMaxFrameSize must be less than or\n                    equal to the corresponding ifMtu for this frame\n                    relay UNI/NNI logical port.')
frPVCEndptInBc = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setUnits('Bits').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frPVCEndptInBc.setDescription('The value of this object is equal to the\n                    committed burst size (Bc) parameter (measured in\n                    bits) for this PVC end-point in the ingress\n                    direction (into the frame relay network).\n\n                    Note that the max value of this range is lower\n                    than the max value allowed by Q.933 (16383 *\n                    10**6).\n\n\n                    Note that the value is encoded in bits whilst the\n                    Q.933 Link layer core parameters information\n                    element encodes this information using octet\n                    units.')
frPVCEndptInBe = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setUnits('Bits').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frPVCEndptInBe.setDescription('The value of this object is equal to the excess\n                    burst size (Be) parameter (measured in bits) for\n                    this PVC end-point in the ingress direction (into\n                    the frame relay network).\n\n                    Note that the max value of this range is lower\n                    than the max value allowed by Q.933 (16383 *\n                    10**6).\n\n                    Note that the value is encoded in bits whilst the\n                    Q.933 Link layer core parameters information\n                    element encodes this information using octet\n                    units.')
frPVCEndptInCIR = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setUnits('Bits per Second').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frPVCEndptInCIR.setDescription('The value of this object is equal to the\n                    committed information rate (CIR) parameter\n                    (measured in bits per second) for this PVC end-\n                    point in the ingress direction (into the frame\n                    relay network).\n\n                    Note that the max value of this range is lower\n                    than the max value allowed by Q.933 (2047 *\n                    10**6).')
frPVCEndptOutMaxFrameSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,4096)).clone(1600)).setUnits('Octets').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frPVCEndptOutMaxFrameSize.setDescription('The value of this object is the size in octets of\n                    the largest frame relay information field for this\n                    PVC end-point in the egress direction (out of the\n                    frame relay network).  The value of\n                    frPVCEndptOutMaxFrameSize must be less than or\n                    equal to the corresponding ifMtu for this frame\n                    relay UNI/NNI logical port.')
frPVCEndptOutBc = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setUnits('Bits').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frPVCEndptOutBc.setDescription('The value of this object is equal to the\n                    committed burst size (Bc) parameter (measured in\n                    bits) for this PVC end-point in the egress\n                    direction (out of the frame relay network).\n\n                    Note that the max value of this range is lower\n                    than the max value allowed by Q.933 (16383 *\n                    10**6).\n\n                    Note that the value is encoded in bits whilst the\n                    Q.933 Link layer core parameters information\n                    element encodes this information using octet\n                    units.')
frPVCEndptOutBe = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setUnits('Bits').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frPVCEndptOutBe.setDescription('The value of this object is equal to the excess\n                    burst size (Be) parameter (measured in bits) for\n\n                    this PVC end-point in the egress direction (out of\n                    the frame relay network).\n\n                    Note that the max value of this range is lower\n                    than the max value allowed by Q.933 (16383 *\n                    10**6).\n\n                    Note that the value is encoded in bits whilst the\n                    Q.933 Link layer core parameters information\n                    element encodes this information using octet\n                    units.')
frPVCEndptOutCIR = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 9), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setUnits('Bits per Second').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frPVCEndptOutCIR.setDescription('The value of this object is equal to the\n                    committed information rate (CIR) parameter\n                    (measured in bits per second) for this PVC end-\n                    point in the egress direction (out of the frame\n                    relay network).\n\n                    Note that the max value of this range is lower\n                    than the max value allowed by Q.933 (2047 *\n                    10**6).')
frPVCEndptConnectIdentifier = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 10), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptConnectIdentifier.setDescription('This object is used to associate PVC end-points\n                    as being part of one PVC segment connection. This\n                    value of this object is equal to the value of\n                    frPVCConnectIndex, which is used as one of the\n                    indices into the frPVCConnectTable.\n\n                    A connection that has been cross-connected via the\n                    FR/ATM PVC Service IWF cross-connect table will\n                    return the value zero when this object is read. In\n                    case of these interworked connections, the\n                    frPVCEndptAtmIwfConnIndex object must be accessed\n\n                    to select the entry in the FR/ATM PVC Service IWF\n                    cross-connect table.\n\n                    The value of this object is provided by the agent,\n                    after the associated entries in the\n                    frPVCConnectTable or frAtmIwfConnectionTable have\n                    been created.')
frPVCEndptRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 11), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frPVCEndptRowStatus.setDescription("This object is used to create new rows in this\n                    table, modify existing rows, and to delete\n                    existing rows.  To create a new PVC, the entries\n                    for the PVC segment end-points in the\n                    frPVCEndptTable must first be created.  Next, the\n                    frPVCConnectTable is used to associate the frame\n                    relay PVC segment end-points.  In order for the\n                    manager to have the necessary error diagnostics,\n                    the frPVCEndptRowStatus object must initially be\n                    set to `createAndWait(5)'.  While the\n                    frPVCEndptRowStatus object is in the\n                    `createAndWait(5)' state, the manager can set each\n                    columnar object and get the necessary error\n                    diagnostics.  The frPVCEndptRowStatus object may\n                    not be set to `active(1)' unless the following\n                    columnar objects exist in this row:\n                    frPVCEndptInMaxFrameSize, frPVCEndptInBc,\n                    frPVCEndptInBe, frPVCEndptInCIR,\n                    frPVCEndptOutMaxFrameSize, frPVCEndptOutBc,\n                    frPVCEndptOutBe, and frPVCEndptOutCIR.")
frPVCEndptRcvdSigStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 12), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("deleted", 1), ("active", 2), ("inactive", 3), ("none", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptRcvdSigStatus.setDescription('The value of this object identifies the PVC\n                    status received via the local in-channel signaling\n\n                    procedures for this PVC end-point.  This object is\n                    only pertinent for interfaces that perform the\n                    bidirectional procedures.\n\n                    Each value has the following meaning:\n                      deleted(1):  This PVC is not listed in the full\n                                   status reports received from the\n                                   user device.  The object retains\n                                   this value for as long as the PVC\n                                   is not listed in the full status\n                                   reports\n\n                    active(2):   This PVC is reported as active, or\n                                   operational, by the user device.\n\n                      inactive(3): This PVC is reported as inactive,\n                                   or non-operational, by the user\n                                   device.\n\n                      none(4):     This interface is only using the\n                                   network-side in-channel signaling\n                                   procedures, so this object does\n                                   not apply.')
frPVCEndptInFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 13), Counter32()).setUnits('Frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptInFrames.setDescription('The number of frames received by the network\n                    (ingress) for this PVC end-point. This includes\n                    any frames discarded by the network due to\n                    submitting more than Bc + Be data or due to any\n                    network congestion recovery procedures.')
frPVCEndptOutFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 14), Counter32()).setUnits('Frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptOutFrames.setDescription('The number of frames sent by the network (egress)\n                    regardless of whether they are Bc or Be frames for\n                    this PVC end-point.')
frPVCEndptInDEFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 15), Counter32()).setUnits('Frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptInDEFrames.setDescription('The number of frames received by the network\n                    (ingress) with the DE bit set to (1) for this PVC\n                    end-point.')
frPVCEndptInExcessFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 16), Counter32()).setUnits('Frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptInExcessFrames.setDescription('The number of frames received by the network\n                    (ingress) for this PVC end-point which were\n                    treated as excess traffic.  Frames which are sent\n                    to the network with DE set to zero are treated as\n                    excess when more than Bc bits are submitted to the\n                    network during the Committed Information Rate\n                    Measurement Interval (Tc).  Excess traffic may or\n                    may not be discarded at the ingress if more than\n                    Bc + Be bits are submitted to the network during\n                    Tc.  Traffic discarded at the ingress is not\n                    recorded in frPVCEndptInExcessFrames.  Frames\n                    which are sent to the network with DE set to one\n                    are also treated as excess traffic.')
frPVCEndptOutExcessFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 17), Counter32()).setUnits('Frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptOutExcessFrames.setDescription('The number of frames sent by the network (egress)\n                    for this PVC end-point which were treated as\n                    excess traffic.  (The DE bit may be set to one.)')
frPVCEndptInDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 18), Counter32()).setUnits('Frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptInDiscards.setDescription('The number of frames received by the network\n                    (ingress) that were discarded due to traffic\n                    enforcement for this PVC end-point.  Congestion\n                    discards are not counted in this object.')
frPVCEndptInOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 19), Counter32()).setUnits('Octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptInOctets.setDescription('The number of octets received by the network\n                    (ingress) for this PVC end-point.  This counter\n                    should only count octets from the beginning of the\n                    frame relay header field to the end of user data.\n                    If the network supporting frame relay can not\n                    count octets, then this count should be an\n                    approximation.')
frPVCEndptOutOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 20), Counter32()).setUnits('Octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptOutOctets.setDescription('The number of octets sent by the network (egress)\n                    for this PVC end-point.  This counter should only\n                    count octets from the beginning of the frame relay\n                    header field to the end of user data.  If the\n                    network supporting frame relay can not count\n                    octets, then this count should be an\n                    approximation.')
frPVCEndptInDiscardsDESet = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 21), Counter32()).setUnits('Frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptInDiscardsDESet.setDescription('The number of frames received by the network\n                    (ingress) that were discarded with the DE bit set\n                    due to traffic enforcement for this PVC end-point.\n                    Congestion discards are not counted in this\n                    object.')
frPVCEndptInFramesFECNSet = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 22), Counter32()).setUnits('Frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptInFramesFECNSet.setDescription('The number of frames received by the network\n                    (ingress) that have the FECN bit set for this PVC\n                    end-point.')
frPVCEndptOutFramesFECNSet = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 23), Counter32()).setUnits('Frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptOutFramesFECNSet.setDescription('The number of frames sent by the network (egress)\n                    that have the FECN bit set for this PVC end-\n                    point.')
frPVCEndptInFramesBECNSet = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 24), Counter32()).setUnits('Frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptInFramesBECNSet.setDescription('The number of frames received by the network\n                    (ingress) that have the BECN bit set for this PVC\n                    end-point.')
frPVCEndptOutFramesBECNSet = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 25), Counter32()).setUnits('Frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptOutFramesBECNSet.setDescription('The number of frames sent by the network (egress)\n                    that have the BECN bit set for this PVC end-\n                    point.')
frPVCEndptInCongDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 26), Counter32()).setUnits('Frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptInCongDiscards.setDescription('The number of frames received by the network\n                    (ingress) that were discarded due to input buffer\n                    congestion, rather than traffic enforcement, for\n                    this PVC end-point.')
frPVCEndptInDECongDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 27), Counter32()).setUnits('Frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptInDECongDiscards.setDescription('The number of frames counted by\n                    frPVCEndptInCongDiscards with the DE bit set to\n                    (1).')
frPVCEndptOutCongDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 28), Counter32()).setUnits('Frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptOutCongDiscards.setDescription('The number of frames sent by the network (egress)\n                    that were discarded due to output buffer\n                    congestion for this PVC end-point.')
frPVCEndptOutDECongDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 29), Counter32()).setUnits('Frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptOutDECongDiscards.setDescription('The number of frames counted by\n                    frPVCEndptOutCongDiscards with the DE bit set to\n                    (1).')
frPVCEndptOutDEFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 30), Counter32()).setUnits('Frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptOutDEFrames.setDescription('The number of frames sent by the network (egress)\n                    with the DE bit set to (1) for this PVC end-\n                    point.')
frPVCEndptAtmIwfConnIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 3, 1, 31), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCEndptAtmIwfConnIndex.setDescription('This object contains the index value of the\n                    FR/ATM cross-connect table entry used to link the\n                    frame relay PVC with an ATM PVC.\n\n                    Each row of the frPVCEndptTable that is not\n                    cross-connected with an ATM PVC must return the\n                    value zero when this object is read.\n\n                    The value of this object is initialized by the\n                    agent after the associated entries in the\n                    frAtmIwfConnectionTable have been created.\n\n                    The value of this object is reset to zero\n                    following destruction of the associated entry in\n                    the frAtmIwfConnectionTable')
frPVCConnectIndexValue = MibScalar((1, 3, 6, 1, 2, 1, 10, 44, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCConnectIndexValue.setDescription('This object returns a hint to be used for\n                    frPVCConnectIndex when creating entries in the\n                    frPVCConnectTable.\n\n                    The value 0 indicates that no unassigned entries\n                    are available.\n\n                    To obtain the frPVCConnectIndex value for a new\n                    entry, the manager issues a management protocol\n                    retrieval operation to obtain the current value of\n                    this object.  After each retrieval, the agent must\n\n                    modify the value to the next unassigned index to\n                    prevent assignment of the same value to multiple\n                    management systems.\n\n                    A management system should repeat the read to\n                    obtain a new value should an attempt to create the\n                    new row using the previously returned hint fail.')
frPVCConnectTable = MibTable((1, 3, 6, 1, 2, 1, 10, 44, 1, 5), )
if mibBuilder.loadTexts: frPVCConnectTable.setDescription("The Frame Relay PVC Connect Table is used to\n                    model the bi-directional PVC segment flows\n                    including:  point-to-point PVCs, point-to-\n                    multipoint PVCs, and multipoint-to-multipoint\n                    PVCs.\n\n                    This table has read-create access and is used to\n                    associate PVC end-points together as belonging to\n                    one connection.  The frPVCConnectIndex is used to\n                    associate all the bi-directional flows.  Not all\n                    implementations will support the capability of\n                    creating/modifying/deleting PVCs using SNMP as a\n                    feature of frame relay CNM service.\n\n                    Once the entries in the frPVCEndptTable are\n                    created, the following step are used to associate\n                    the PVC end-points as belonging to one PVC\n                    connection:\n\n                    1)  Obtain a unique frPVCConnectIndex\n                        using the frPVCConnectIndexValue object.\n\n                    2)  Connect the PVC segment endpoints together\n                        with the applicable frPVCConnectIndex value\n                        obtained via  frPVCConnectIndexValue.  The\n                        entries in this table are created by using\n                        the frPVCConnectRowStatus object.\n\n                    3)  The agent will provide the value of the\n                        corresponding instances of\n                        frPVCEndptConnectIdentifier with the\n                        frPVCConnectIndex value.\n\n                    4)  Set frPVCConnectAdminStatus to `active(1)' in\n\n                        all rows for this PVC segment to turn the\n                        PVC on.\n\n                    For example, the Frame Relay PVC Connection Group\n                    models a bi-directional, point-to-point PVC\n                    segment as one entry in this table.\n\n                    Frame Relay                           Frame Relay\n                     Network                                 Network\n                     Low Port                               High Port\n                             __________________________________\n                            |                                  |\n                       _____| >> from low to high PVC flow  >> |_____\n                            | << from high to low PVC flow  << |\n                            |__________________________________|\n\n                    The terms low and high are chosen to represent\n                    numerical ordering of a PVC segment's endpoints\n                    for representation in this table.  That is, the\n                    endpoint with the lower value of ifIndex is termed\n                    'low', while the opposite endpoint of the segment\n                    is termed 'high'.  This terminology is to provide\n                    directional information; for example the\n                    frPVCConnectL2hOperStatus and\n                    frPVCConnectH2lOperStatus as illustrated above.\n\n                    If the Frame Relay Connection table is used to\n                    model a unidirectional PVC, then one direction\n                    (either from low to high or from high to low) has\n                     its Operational Status equal to down.\n\n                     A PVC segment is a portion of a PVC that traverses\n                    one Frame Relay Network, and a PVC segment is\n                    identified by its two end-points (UNI/NNI logical\n                    port index value and DLCI index value) through one\n                    Frame Relay Network.")
frPVCConnectEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 44, 1, 5, 1), ).setIndexNames((0, "FRNETSERV-MIB", "frPVCConnectIndex"), (0, "FRNETSERV-MIB", "frPVCConnectLowIfIndex"), (0, "FRNETSERV-MIB", "frPVCConnectLowDLCIIndex"), (0, "FRNETSERV-MIB", "frPVCConnectHighIfIndex"), (0, "FRNETSERV-MIB", "frPVCConnectHighDLCIIndex"))
if mibBuilder.loadTexts: frPVCConnectEntry.setDescription('An entry in the Frame Relay PVC Connect table.\n                    This entry is used to model a PVC segment in two\n                    directions.')
frPVCConnectIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 5, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647)))
if mibBuilder.loadTexts: frPVCConnectIndex.setDescription('The value of this object is equal to the\n                      frPVCConnectIndexValue obtained to uniquely\n                      identify this PVC segment connection.')
frPVCConnectLowIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 5, 1, 2), InterfaceIndex())
if mibBuilder.loadTexts: frPVCConnectLowIfIndex.setDescription('The value of this object is equal to IF-MIB\n                    ifIndex value of the UNI/NNI logical port for this\n                    PVC segment.  The term low implies that this PVC\n                    segment end-point has the numerically lower\n                    ifIndex value than the connected/associated PVC\n                    segment end-point.\n\n                    RFC 1604 permitted a zero value for this object to\n                    identify termination at a non-frame relay\n                    interface.  However, this cross-connect table is\n                    limited to frame relay connections.  See the frame\n\n                    relay/ATM IWF MIB [28] for the cross-connect table\n                    used for those types of connections.')
frPVCConnectLowDLCIIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 5, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(16,4194303)))
if mibBuilder.loadTexts: frPVCConnectLowDLCIIndex.setDescription('The value of this object is equal to the DLCI\n                    value for this end-point of the PVC segment.')
frPVCConnectHighIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 5, 1, 4), InterfaceIndex())
if mibBuilder.loadTexts: frPVCConnectHighIfIndex.setDescription('The value of this object is equal to IF-MIB\n                    ifIndex value for the UNI/NNI logical port for\n                    this PVC segment.  The term high implies that this\n                    PVC segment end-point has the numerically higher\n                    ifIndex value than the connected/associated PVC\n                    segment end-point.')
frPVCConnectHighDLCIIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 5, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(16,4194303)))
if mibBuilder.loadTexts: frPVCConnectHighDLCIIndex.setDescription('The value of this object is equal to the egress\n                    DLCI value for this end-point of the PVC segment.')
frPVCConnectAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 5, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("active", 1), ("inactive", 2), ("testing", 3),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frPVCConnectAdminStatus.setDescription("The value of this object identifies the desired\n                    administrative status of this bi-directional PVC\n\n                    segment.  The active(1) state means the PVC\n                    segment is currently operational; the inactive(2)\n                    state means the PVC segment is currently not\n                    operational; the testing(3) state means the PVC\n                    segment is currently undergoing a test.  This\n                    state is set by an administrative entity.  This\n                    value affects the PVC status indicated across the\n                    ingress NNI/UNI of both end-points of the bi-\n                    directional PVC segment.  When a PVC segment\n                    connection is created using this table, this\n                    object is initially set to `inactive(2)'.  After\n                    the frPVCConnectRowStatus object is set to\n                    `active(1)' (and the corresponding/associated\n                    entries in the frPVCEndptTable have their\n                    frPVCEndptRowStatus object set to `active(1)'),\n                    the frPVCConnectAdminStatus object may be set to\n                    `active(1)' to turn on the PVC segment\n                    connection.")
frPVCConnectL2hOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 5, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("active", 1), ("inactive", 2), ("testing", 3), ("unknown", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCConnectL2hOperStatus.setDescription('The value of this object identifies the current\n                    operational status of the PVC segment connection\n                    in one direction; (i.e., in the low to high\n                    direction). This value affects the PVC status\n                    indicated across the ingress NNI/UNI (low side) of\n                    the PVC segment.\n\n                    The values mean:\n\n                    active(1)   - PVC is currently operational\n\n                    inactive(2) - PVC is currently not operational.\n                                  This may be because of an underlying\n                                  LMI or DS1 failure.\n\n                    testing(3)  - PVC is currently undergoing a test.\n                                  This may be because of an underlying\n                                  frLport or DS1 undergoing a test.\n\n                    unknown(4)  - the status of the PVC currently can\n                                  not be determined.')
frPVCConnectH2lOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 5, 1, 8), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("active", 1), ("inactive", 2), ("testing", 3), ("unknown", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCConnectH2lOperStatus.setDescription('The value of this object identifies the current\n                    operational status of the PVC segment connection\n                    in one direction; (i.e., in the high to low\n                    direction)..  This value affects the PVC status\n                    indicated across the ingress NNI/UNI (high side)\n                    of the PVC segment.\n\n                    The values mean:\n\n                    active(1)   - PVC is currently operational\n\n                    inactive(2) - PVC is currently not operational.\n                                  This may be because of an underlying\n                                  LMI or DS1 failure.\n\n                    testing(3)  - PVC is currently undergoing a test.\n                                  This may be because of an underlying\n                                  frLport or DS1 undergoing a test.\n\n                    unknown(4)  - the status of the PVC currently can\n                                  not be determined.')
frPVCConnectL2hLastChange = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 5, 1, 9), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCConnectL2hLastChange.setDescription("The value of the Interface MIB's sysUpTime object\n                    at the time this PVC segment entered its current\n                    operational state in the low to high direction.\n                    If the current state was entered prior to the last\n                    re-initialization of the FRS agent, then this\n                    object contains a zero value.")
frPVCConnectH2lLastChange = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 5, 1, 10), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frPVCConnectH2lLastChange.setDescription("The value of the Interface MIB's sysUpTime object\n                    at the time this PVC segment entered its current\n                    operational state in the high to low direction.\n                    If the current state was entered prior to the last\n                    re-initialization of the FRS agent, then this\n                    object contains a zero value.")
frPVCConnectRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 5, 1, 11), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frPVCConnectRowStatus.setDescription("The status of this entry in the\n                    frPVCConnectTable.  This variable is used to\n                    create new connections for the PVC end-points and\n                    to change existing connections of the PVC end-\n                    points.  This object must be initially set to\n                    `createAndWait(5)'. In this state, the agent\n                    checks the parameters in the associated entries in\n                    the frPVCEndptTable to verify that the PVC end-\n                    points can be connected (i.e., the In parameters\n                    for one PVC end-point are equal to the Out\n                    parameters for the other PVC end-point).  This\n                    object can not be set to `active(1)' unless the\n                    following columnar object exists in this row:\n                    frPVCConnectAdminStatus.  The agent also supplies\n                    the associated value of frPVCConnectIndex for the\n                    frPVCEndptConnectIdentifier instances.  To turn on\n                    a PVC segment connection, the\n                    frPVCConnectAdminStatus is set to `active(1)'.")
frPVCConnectUserName = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 5, 1, 12), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frPVCConnectUserName.setDescription('This is a service user assigned textual\n                    representation of a PVC.')
frPVCConnectProviderName = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 5, 1, 13), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frPVCConnectProviderName.setDescription('This is a system supplied textual representation\n                    of PVC.  It is assigned by the service provider.')
frAccountPVCTable = MibTable((1, 3, 6, 1, 2, 1, 10, 44, 1, 6), )
if mibBuilder.loadTexts: frAccountPVCTable.setDescription('The Frame Relay Accounting PVC table.  This table\n                    is used to perform accounting on a PVC segment\n                    end-point basis.')
frAccountPVCEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 44, 1, 6, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "FRNETSERV-MIB", "frAccountPVCDLCIIndex"))
if mibBuilder.loadTexts: frAccountPVCEntry.setDescription('An entry in the Frame Relay Accounting PVC\n                    table.')
frAccountPVCDLCIIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 6, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(16,4194303)))
if mibBuilder.loadTexts: frAccountPVCDLCIIndex.setDescription('The value of this object is equal to the DLCI\n\n                    value for this PVC segment end-point.')
frAccountPVCSegmentSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 6, 1, 2), Integer32()).setUnits('Octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: frAccountPVCSegmentSize.setDescription('The value of this object is equal to the Segment\n                    Size for this PVC segment end-point.')
frAccountPVCInSegments = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 6, 1, 3), Counter32()).setUnits('Segments').setMaxAccess("readonly")
if mibBuilder.loadTexts: frAccountPVCInSegments.setDescription('The value of this object is equal to the number\n                    of segments received by this PVC segment end-\n                    point.')
frAccountPVCOutSegments = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 6, 1, 4), Counter32()).setUnits('Segments').setMaxAccess("readonly")
if mibBuilder.loadTexts: frAccountPVCOutSegments.setDescription('The value of this object is equal to the number\n                    of segments sent by this PVC segment end-point.')
frAccountLportTable = MibTable((1, 3, 6, 1, 2, 1, 10, 44, 1, 7), )
if mibBuilder.loadTexts: frAccountLportTable.setDescription('The Frame Relay Accounting Logical Port table.\n                    This table is used to perform accounting on a\n                    UNI/NNI Logical Port basis.')
frAccountLportEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 44, 1, 7, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: frAccountLportEntry.setDescription('An entry in the Frame Relay Accounting Logical\n                    Port table.')
frAccountLportSegmentSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 7, 1, 1), Integer32()).setUnits('Octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: frAccountLportSegmentSize.setDescription('The value of this object is equal to the Segment\n                    Size for this UNI/NNI logical port.')
frAccountLportInSegments = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 7, 1, 2), Counter32()).setUnits('Segments').setMaxAccess("readonly")
if mibBuilder.loadTexts: frAccountLportInSegments.setDescription('The value of this object is equal to the number\n                    of segments received by this UNI/NNI logical\n                    port.')
frAccountLportOutSegments = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 44, 1, 7, 1, 3), Counter32()).setUnits('Segments').setMaxAccess("readonly")
if mibBuilder.loadTexts: frAccountLportOutSegments.setDescription('The value of this object is equal to the number\n\n                    of segments sent by this UNI/NNI logical port.')
frPVCConnectStatusChange = NotificationType((1, 3, 6, 1, 2, 1, 10, 44, 2, 1)).setObjects(*(("FRNETSERV-MIB", "frPVCConnectIndex"), ("FRNETSERV-MIB", "frPVCConnectLowIfIndex"), ("FRNETSERV-MIB", "frPVCConnectLowDLCIIndex"), ("FRNETSERV-MIB", "frPVCConnectHighIfIndex"), ("FRNETSERV-MIB", "frPVCConnectHighDLCIIndex"), ("FRNETSERV-MIB", "frPVCConnectL2hOperStatus"), ("FRNETSERV-MIB", "frPVCConnectH2lOperStatus"), ("FRNETSERV-MIB", "frPVCEndptRcvdSigStatus"),))
if mibBuilder.loadTexts: frPVCConnectStatusChange.setDescription('Refer to the description of the\n                    frPVCConnectStatusNotif notification that has\n                    replaced this notification.  The notification is\n                    deprecated due to the incorrect inclusion of index\n                    values and to take advantage of the trap prefix\n                    for automatic conversion from SMIv2 to SMIv1 by\n                    making the one but last sub-ID a zero (i.e. the\n                    so-called trap prefix).')
frPVCConnectStatusNotif = NotificationType((1, 3, 6, 1, 2, 1, 10, 44, 2, 0, 2)).setObjects(*(("FRNETSERV-MIB", "frPVCConnectL2hOperStatus"), ("FRNETSERV-MIB", "frPVCConnectH2lOperStatus"), ("FRNETSERV-MIB", "frPVCEndptRcvdSigStatus"),))
if mibBuilder.loadTexts: frPVCConnectStatusNotif.setDescription('This notification indicates that the indicated\n                    PVC has changed state.\n\n                    This notification is not sent if an FR-UNI changes\n                    state; a linkDown or linkUp notification should be\n                    sent instead.  The first instance of\n                    frPVCEndptRcvdSigStatus is for the endpoint with\n                    LowIfIndex, LowDLCIIndex.  The second instance of\n                    frPVCEndptRcvdSigStatus is for the endpoint with\n                    HighIfIndex, HighDLCIIndex')
frnetservConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 44, 3))
frnetservGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 44, 3, 1))
frnetservCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 44, 3, 2))
frnetservCompliance2 = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 44, 3, 2, 2)).setObjects(*(("FRNETSERV-MIB", "frnetservLportGroup2"), ("FRNETSERV-MIB", "frnetservMgtVCSigGroup"), ("FRNETSERV-MIB", "frnetservPVCEndptGroup"), ("FRNETSERV-MIB", "frnetservPVCEndptGroup2"), ("FRNETSERV-MIB", "frnetservPVCConnectGroup"), ("FRNETSERV-MIB", "frnetservPVCConnectNamesGroup"), ("FRNETSERV-MIB", "frnetservPVCNotifGroup2"), ("FRNETSERV-MIB", "frnetservAccountPVCGroup"), ("FRNETSERV-MIB", "frnetservAccountLportGroup"),))
if mibBuilder.loadTexts: frnetservCompliance2.setDescription("The compliance statement for SNMP entities which\n                    have Frame Relay Network Service Interfaces.\n\n                    The distinction between 'service' and 'switch' is\n                    that a 'switch' is configured via this MIB.\n                    Hence, the various read/write objects have write\n                    capability.  A 'service' represents a passive\n                    monitor-only customer network management\n                    interface.  The various read/write objects are\n                    restricted to read-only capability.")
frnetSwitchCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 44, 3, 2, 3)).setObjects(*(("FRNETSERV-MIB", "frnetservLportGroup2"), ("FRNETSERV-MIB", "frnetservLportAdminGroup"), ("FRNETSERV-MIB", "frnetservMgtVCSigGroup"), ("FRNETSERV-MIB", "frnetservMgtVCSigAdminGroup"), ("FRNETSERV-MIB", "frnetservPVCEndptGroup"), ("FRNETSERV-MIB", "frnetservPVCEndptGroup2"), ("FRNETSERV-MIB", "frnetservPVCConnectGroup"), ("FRNETSERV-MIB", "frnetservPVCConnectNamesGroup"), ("FRNETSERV-MIB", "frnetservPVCNotifGroup2"), ("FRNETSERV-MIB", "frnetservAccountPVCGroup"), ("FRNETSERV-MIB", "frnetservAccountLportGroup"),))
if mibBuilder.loadTexts: frnetSwitchCompliance.setDescription("The compliance statement for SNMP entities which\n                    have Frame Relay Network Switch objects.\n\n                    The distinction between 'service' and 'switch' is\n                    that a 'switch' is configured via this MIB.\n\n                    Hence, the various read/write objects have write\n                    capability.  A 'service' represents a passive\n                    monitor-only customer network management\n                    interface.  The various read/write objects are\n                    restricted to read-only capability.")
frnetservCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 44, 3, 2, 1)).setObjects(*(("FRNETSERV-MIB", "frnetservLportGroup"), ("FRNETSERV-MIB", "frnetservMgtVCSigGroup"), ("FRNETSERV-MIB", "frnetservPVCEndptGroup"), ("FRNETSERV-MIB", "frnetservPVCConnectGroup"), ("FRNETSERV-MIB", "frnetservAccountPVCGroup"), ("FRNETSERV-MIB", "frnetservAccountLportGroup"),))
if mibBuilder.loadTexts: frnetservCompliance.setDescription('The compliance statement for SNMP entities which\n                    have Frame Relay Network Service Interfaces.\n\n                    This compliance statement has been deprecated in\n                    favor of frnetservCompliance2.  The new compliance\n                    module expands the mandatory groups to include\n                    notification and other new objects.')
frnetservLportGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 44, 3, 1, 1)).setObjects(*(("FRNETSERV-MIB", "frLportNumPlan"), ("FRNETSERV-MIB", "frLportContact"), ("FRNETSERV-MIB", "frLportLocation"), ("FRNETSERV-MIB", "frLportType"), ("FRNETSERV-MIB", "frLportAddrDLCILen"), ("FRNETSERV-MIB", "frLportVCSigProtocol"), ("FRNETSERV-MIB", "frLportVCSigPointer"),))
if mibBuilder.loadTexts: frnetservLportGroup.setDescription('A collection of objects providing information\n                     applicable to a Frame Relay Logical Port.  This\n                     group has been deprecated to eliminate reference\n\n                     to the object frLportVCSigPointer.\n\n                     Use the new group frnetservLportGroup2 as a\n                     replacement for this group.')
frnetservMgtVCSigGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 44, 3, 1, 2)).setObjects(*(("FRNETSERV-MIB", "frMgtVCSigProced"), ("FRNETSERV-MIB", "frMgtVCSigUserN391"), ("FRNETSERV-MIB", "frMgtVCSigUserN392"), ("FRNETSERV-MIB", "frMgtVCSigUserN393"), ("FRNETSERV-MIB", "frMgtVCSigUserT391"), ("FRNETSERV-MIB", "frMgtVCSigNetN392"), ("FRNETSERV-MIB", "frMgtVCSigNetN393"), ("FRNETSERV-MIB", "frMgtVCSigNetT392"), ("FRNETSERV-MIB", "frMgtVCSigNetnN4"), ("FRNETSERV-MIB", "frMgtVCSigNetnT3"), ("FRNETSERV-MIB", "frMgtVCSigUserLinkRelErrors"), ("FRNETSERV-MIB", "frMgtVCSigUserProtErrors"), ("FRNETSERV-MIB", "frMgtVCSigUserChanInactive"), ("FRNETSERV-MIB", "frMgtVCSigNetLinkRelErrors"), ("FRNETSERV-MIB", "frMgtVCSigNetProtErrors"), ("FRNETSERV-MIB", "frMgtVCSigNetChanInactive"),))
if mibBuilder.loadTexts: frnetservMgtVCSigGroup.setDescription('A collection of objects providing information\n                    applicable to the Local In-Channel Signaling\n                    Procedures used for a UNI/NNI logical port.')
frnetservPVCEndptGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 44, 3, 1, 3)).setObjects(*(("FRNETSERV-MIB", "frPVCConnectIndexValue"), ("FRNETSERV-MIB", "frPVCEndptInMaxFrameSize"), ("FRNETSERV-MIB", "frPVCEndptInBc"), ("FRNETSERV-MIB", "frPVCEndptInBe"), ("FRNETSERV-MIB", "frPVCEndptInCIR"), ("FRNETSERV-MIB", "frPVCEndptOutMaxFrameSize"), ("FRNETSERV-MIB", "frPVCEndptOutBc"), ("FRNETSERV-MIB", "frPVCEndptOutBe"), ("FRNETSERV-MIB", "frPVCEndptOutCIR"), ("FRNETSERV-MIB", "frPVCEndptConnectIdentifier"), ("FRNETSERV-MIB", "frPVCEndptRowStatus"), ("FRNETSERV-MIB", "frPVCEndptRcvdSigStatus"), ("FRNETSERV-MIB", "frPVCEndptInFrames"), ("FRNETSERV-MIB", "frPVCEndptOutFrames"), ("FRNETSERV-MIB", "frPVCEndptInDEFrames"), ("FRNETSERV-MIB", "frPVCEndptInExcessFrames"), ("FRNETSERV-MIB", "frPVCEndptOutExcessFrames"), ("FRNETSERV-MIB", "frPVCEndptInDiscards"), ("FRNETSERV-MIB", "frPVCEndptInOctets"), ("FRNETSERV-MIB", "frPVCEndptOutOctets"),))
if mibBuilder.loadTexts: frnetservPVCEndptGroup.setDescription('A collection of objects providing information\n                    applicable to a Frame Relay PVC end-point.')
frnetservPVCConnectGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 44, 3, 1, 4)).setObjects(*(("FRNETSERV-MIB", "frPVCConnectAdminStatus"), ("FRNETSERV-MIB", "frPVCConnectL2hOperStatus"), ("FRNETSERV-MIB", "frPVCConnectH2lOperStatus"), ("FRNETSERV-MIB", "frPVCConnectL2hLastChange"), ("FRNETSERV-MIB", "frPVCConnectH2lLastChange"), ("FRNETSERV-MIB", "frPVCConnectRowStatus"),))
if mibBuilder.loadTexts: frnetservPVCConnectGroup.setDescription('A collection of objects providing information\n                    applicable to a Frame Relay PVC connection.')
frnetservAccountPVCGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 44, 3, 1, 5)).setObjects(*(("FRNETSERV-MIB", "frAccountPVCSegmentSize"), ("FRNETSERV-MIB", "frAccountPVCInSegments"), ("FRNETSERV-MIB", "frAccountPVCOutSegments"),))
if mibBuilder.loadTexts: frnetservAccountPVCGroup.setDescription('A collection of objects providing accounting\n                    information application to a Frame Relay PVC end-\n                    point.')
frnetservAccountLportGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 44, 3, 1, 6)).setObjects(*(("FRNETSERV-MIB", "frAccountLportSegmentSize"), ("FRNETSERV-MIB", "frAccountLportInSegments"), ("FRNETSERV-MIB", "frAccountLportOutSegments"),))
if mibBuilder.loadTexts: frnetservAccountLportGroup.setDescription('A collection of objects providing accounting\n                    information application to a Frame Relay logical\n                    port.')
frnetservLportGroup2 = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 44, 3, 1, 7)).setObjects(*(("FRNETSERV-MIB", "frLportNumPlan"), ("FRNETSERV-MIB", "frLportContact"), ("FRNETSERV-MIB", "frLportLocation"), ("FRNETSERV-MIB", "frLportType"), ("FRNETSERV-MIB", "frLportAddrDLCILen"), ("FRNETSERV-MIB", "frLportVCSigProtocol"), ("FRNETSERV-MIB", "frLportFragControl"), ("FRNETSERV-MIB", "frLportFragSize"),))
if mibBuilder.loadTexts: frnetservLportGroup2.setDescription('A collection of objects providing information\n                    applicable to a Frame Relay Logical Port.\n\n                    This new version of the Logical Port Group\n                    eliminates the frLportVCSigPointer and adds\n                    support for fragmentation.')
frnetservPVCEndptGroup2 = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 44, 3, 1, 8)).setObjects(*(("FRNETSERV-MIB", "frPVCEndptInDiscardsDESet"), ("FRNETSERV-MIB", "frPVCEndptInFramesFECNSet"), ("FRNETSERV-MIB", "frPVCEndptOutFramesFECNSet"), ("FRNETSERV-MIB", "frPVCEndptInFramesBECNSet"), ("FRNETSERV-MIB", "frPVCEndptOutFramesBECNSet"), ("FRNETSERV-MIB", "frPVCEndptInCongDiscards"), ("FRNETSERV-MIB", "frPVCEndptInDECongDiscards"), ("FRNETSERV-MIB", "frPVCEndptOutCongDiscards"), ("FRNETSERV-MIB", "frPVCEndptOutDECongDiscards"), ("FRNETSERV-MIB", "frPVCEndptOutDEFrames"), ("FRNETSERV-MIB", "frPVCEndptAtmIwfConnIndex"),))
if mibBuilder.loadTexts: frnetservPVCEndptGroup2.setDescription('Additions to the PVC end-point group.  These\n                    additions provide new frame counters to track\n                    frame loss.  In addition, the new FR/ATM IWF MIB\n                    cross-connect index is included.')
frnetservPVCConnectNamesGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 44, 3, 1, 9)).setObjects(*(("FRNETSERV-MIB", "frPVCConnectUserName"), ("FRNETSERV-MIB", "frPVCConnectProviderName"),))
if mibBuilder.loadTexts: frnetservPVCConnectNamesGroup.setDescription('Additions to the PVC Connect Group.')
frnetservLportAdminGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 44, 3, 1, 10)).setObjects(*(("FRNETSERV-MIB", "frLportDLCIIndexValue"), ("FRNETSERV-MIB", "frLportTypeAdmin"), ("FRNETSERV-MIB", "frLportVCSigProtocolAdmin"),))
if mibBuilder.loadTexts: frnetservLportAdminGroup.setDescription('Administrative (R/W) objects for creating a\n                    switch logical port.')
frnetservMgtVCSigAdminGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 44, 3, 1, 11)).setObjects(*(("FRNETSERV-MIB", "frMgtVCSigProcedAdmin"), ("FRNETSERV-MIB", "frMgtVCSigUserN391Admin"), ("FRNETSERV-MIB", "frMgtVCSigUserN392Admin"), ("FRNETSERV-MIB", "frMgtVCSigUserN393Admin"), ("FRNETSERV-MIB", "frMgtVCSigUserT391Admin"), ("FRNETSERV-MIB", "frMgtVCSigNetN392Admin"), ("FRNETSERV-MIB", "frMgtVCSigNetN393Admin"), ("FRNETSERV-MIB", "frMgtVCSigNetT392Admin"), ("FRNETSERV-MIB", "frMgtVCSigNetnT3Admin"),))
if mibBuilder.loadTexts: frnetservMgtVCSigAdminGroup.setDescription('A collection of objects providing information\n                    applicable to the Local In-Channel Signaling\n                    Procedures used for a UNI/NNI logical port.')
frnetservPVCNotifGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 10, 44, 3, 1, 12)).setObjects(*(("FRNETSERV-MIB", "frPVCConnectStatusChange"),))
if mibBuilder.loadTexts: frnetservPVCNotifGroup.setDescription('Deprecated notification group.  The\n                    frPVCConnectStatusChange notification was flawed\n                    because it included redundant indexes and was not\n                    properly encoded for SMIv1 conversion.')
frnetservPVCNotifGroup2 = NotificationGroup((1, 3, 6, 1, 2, 1, 10, 44, 3, 1, 13)).setObjects(*(("FRNETSERV-MIB", "frPVCConnectStatusNotif"),))
if mibBuilder.loadTexts: frnetservPVCNotifGroup2.setDescription('A collection of notifications that apply to frame\n                    relay PVC Connections ')
mibBuilder.exportSymbols("FRNETSERV-MIB", frPVCConnectHighIfIndex=frPVCConnectHighIfIndex, frAccountPVCDLCIIndex=frAccountPVCDLCIIndex, frnetservPVCConnectNamesGroup=frnetservPVCConnectNamesGroup, frMgtVCSigUserProtErrors=frMgtVCSigUserProtErrors, frMgtVCSigProced=frMgtVCSigProced, frPVCEndptOutOctets=frPVCEndptOutOctets, frMgtVCSigUserN393=frMgtVCSigUserN393, frPVCEndptInDEFrames=frPVCEndptInDEFrames, frPVCConnectIndexValue=frPVCConnectIndexValue, frnetservPVCNotifGroup=frnetservPVCNotifGroup, frMgtVCSigUserN391=frMgtVCSigUserN391, frnetservGroups=frnetservGroups, frMgtVCSigUserN393Admin=frMgtVCSigUserN393Admin, frPVCConnectLowIfIndex=frPVCConnectLowIfIndex, frMgtVCSigUserT391Admin=frMgtVCSigUserT391Admin, frLportTypeAdmin=frLportTypeAdmin, frPVCEndptOutFrames=frPVCEndptOutFrames, frnetservCompliance2=frnetservCompliance2, frPVCEndptOutDEFrames=frPVCEndptOutDEFrames, frPVCConnectStatusChange=frPVCConnectStatusChange, frMgtVCSigNetN392Admin=frMgtVCSigNetN392Admin, frPVCEndptOutBc=frPVCEndptOutBc, frLportType=frLportType, frAccountPVCInSegments=frAccountPVCInSegments, frPVCConnectH2lOperStatus=frPVCConnectH2lOperStatus, frPVCEndptRowStatus=frPVCEndptRowStatus, frMgtVCSigUserChanInactive=frMgtVCSigUserChanInactive, frPVCEndptOutCIR=frPVCEndptOutCIR, frPVCEndptInDiscardsDESet=frPVCEndptInDiscardsDESet, frnetservLportGroup=frnetservLportGroup, frLportFragControl=frLportFragControl, frPVCConnectProviderName=frPVCConnectProviderName, frPVCConnectHighDLCIIndex=frPVCConnectHighDLCIIndex, frnetservObjects=frnetservObjects, frPVCConnectIndex=frPVCConnectIndex, frPVCConnectTable=frPVCConnectTable, frMgtVCSigUserT391=frMgtVCSigUserT391, frPVCConnectEntry=frPVCConnectEntry, frPVCEndptOutExcessFrames=frPVCEndptOutExcessFrames, frAccountPVCOutSegments=frAccountPVCOutSegments, frMgtVCSigTable=frMgtVCSigTable, frLportVCSigProtocolAdmin=frLportVCSigProtocolAdmin, frPVCEndptInDiscards=frPVCEndptInDiscards, frMgtVCSigNetProtErrors=frMgtVCSigNetProtErrors, frnetservMIB=frnetservMIB, frPVCConnectL2hOperStatus=frPVCConnectL2hOperStatus, frAccountLportSegmentSize=frAccountLportSegmentSize, frPVCEndptOutFramesBECNSet=frPVCEndptOutFramesBECNSet, frnetservLportAdminGroup=frnetservLportAdminGroup, frMgtVCSigNetnT3=frMgtVCSigNetnT3, frPVCEndptOutFramesFECNSet=frPVCEndptOutFramesFECNSet, frMgtVCSigNetChanInactive=frMgtVCSigNetChanInactive, frnetservLportGroup2=frnetservLportGroup2, frLportEntry=frLportEntry, frPVCEndptRcvdSigStatus=frPVCEndptRcvdSigStatus, frPVCEndptTable=frPVCEndptTable, frPVCEndptInDECongDiscards=frPVCEndptInDECongDiscards, frnetservPVCNotifGroup2=frnetservPVCNotifGroup2, frPVCEndptInOctets=frPVCEndptInOctets, frPVCConnectRowStatus=frPVCConnectRowStatus, frPVCEndptInFramesFECNSet=frPVCEndptInFramesFECNSet, frPVCEndptOutCongDiscards=frPVCEndptOutCongDiscards, frnetservPVCEndptGroup=frnetservPVCEndptGroup, frMgtVCSigNetnT3Admin=frMgtVCSigNetnT3Admin, frMgtVCSigUserN392=frMgtVCSigUserN392, frMgtVCSigUserLinkRelErrors=frMgtVCSigUserLinkRelErrors, frAccountLportTable=frAccountLportTable, frMgtVCSigNetN392=frMgtVCSigNetN392, frPVCEndptInFrames=frPVCEndptInFrames, frnetservAccountLportGroup=frnetservAccountLportGroup, frPVCConnectLowDLCIIndex=frPVCConnectLowDLCIIndex, frAccountLportInSegments=frAccountLportInSegments, frnetSwitchCompliance=frnetSwitchCompliance, frnetservMgtVCSigGroup=frnetservMgtVCSigGroup, frLportTable=frLportTable, frPVCEndptOutBe=frPVCEndptOutBe, frPVCEndptInExcessFrames=frPVCEndptInExcessFrames, frnetservPVCEndptGroup2=frnetservPVCEndptGroup2, frAccountPVCEntry=frAccountPVCEntry, frMgtVCSigEntry=frMgtVCSigEntry, frPVCEndptEntry=frPVCEndptEntry, frPVCConnectAdminStatus=frPVCConnectAdminStatus, frnetservCompliances=frnetservCompliances, frAccountLportOutSegments=frAccountLportOutSegments, frMgtVCSigNetnN4=frMgtVCSigNetnN4, frMgtVCSigUserN392Admin=frMgtVCSigUserN392Admin, frMgtVCSigProcedAdmin=frMgtVCSigProcedAdmin, frPVCEndptInMaxFrameSize=frPVCEndptInMaxFrameSize, frPVCEndptOutMaxFrameSize=frPVCEndptOutMaxFrameSize, frnetservAccountPVCGroup=frnetservAccountPVCGroup, PYSNMP_MODULE_ID=frnetservMIB, frPVCEndptOutDECongDiscards=frPVCEndptOutDECongDiscards, frLportNumPlan=frLportNumPlan, frPVCEndptInCIR=frPVCEndptInCIR, frnetservPVCConnectGroup=frnetservPVCConnectGroup, frLportVCSigProtocol=frLportVCSigProtocol, frLportLocation=frLportLocation, frMgtVCSigNetT392=frMgtVCSigNetT392, frPVCEndptConnectIdentifier=frPVCEndptConnectIdentifier, frMgtVCSigUserN391Admin=frMgtVCSigUserN391Admin, frMgtVCSigNetLinkRelErrors=frMgtVCSigNetLinkRelErrors, frLportVCSigPointer=frLportVCSigPointer, frAccountPVCSegmentSize=frAccountPVCSegmentSize, frnetservCompliance=frnetservCompliance, frPVCEndptDLCIIndex=frPVCEndptDLCIIndex, frPVCConnectH2lLastChange=frPVCConnectH2lLastChange, frnetservTraps=frnetservTraps, frLportFragSize=frLportFragSize, frMgtVCSigNetN393Admin=frMgtVCSigNetN393Admin, frnetservConformance=frnetservConformance, frnetservMgtVCSigAdminGroup=frnetservMgtVCSigAdminGroup, frPVCConnectL2hLastChange=frPVCConnectL2hLastChange, frnetservTrapsPrefix=frnetservTrapsPrefix, frPVCEndptAtmIwfConnIndex=frPVCEndptAtmIwfConnIndex, frLportAddrDLCILen=frLportAddrDLCILen, frLportDLCIIndexValue=frLportDLCIIndexValue, frMgtVCSigNetT392Admin=frMgtVCSigNetT392Admin, frPVCConnectUserName=frPVCConnectUserName, frAccountPVCTable=frAccountPVCTable, frPVCEndptInFramesBECNSet=frPVCEndptInFramesBECNSet, frPVCEndptInBe=frPVCEndptInBe, frLportContact=frLportContact, frMgtVCSigNetN393=frMgtVCSigNetN393, frPVCEndptInCongDiscards=frPVCEndptInCongDiscards, frPVCConnectStatusNotif=frPVCConnectStatusNotif, frAccountLportEntry=frAccountLportEntry, frPVCEndptInBc=frPVCEndptInBc)



#
# PySNMP MIB module JUNIPER-SMI (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/JUNIPER-SMI
# Produced by pysmi-0.0.7 at Sun Feb 14 00:05:50 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, ConstraintsIntersection, ConstraintsUnion, SingleValueConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ConstraintsIntersection", "ConstraintsUnion", "SingleValueConstraint", "ValueRangeConstraint")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( ObjectIdentity, NotificationType, Counter32, Counter64, IpAddress, MibIdentifier, Bits, ModuleIdentity, Gauge32, Unsigned32, enterprises, TimeTicks, MibScalar, MibTable, MibTableRow, MibTableColumn, iso, Integer32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ObjectIdentity", "NotificationType", "Counter32", "Counter64", "IpAddress", "MibIdentifier", "Bits", "ModuleIdentity", "Gauge32", "Unsigned32", "enterprises", "TimeTicks", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "iso", "Integer32")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
juniperMIB = ModuleIdentity((1, 3, 6, 1, 4, 1, 2636)).setRevisions(("2010-07-09 00:00", "2009-10-29 00:00", "2010-06-18 00:00", "2003-04-17 01:00", "2005-08-17 01:00", "2006-12-14 01:00", "2007-01-01 00:00", "2007-10-09 00:00", "2009-12-31 00:00", "2010-07-14 00:00", "2011-01-26 00:00", "2012-02-10 00:00", "2012-08-01 00:00", "2012-11-01 00:00", "2012-12-07 00:00", "2013-01-25 00:00", "2013-11-26 00:00",))
if mibBuilder.loadTexts: juniperMIB.setLastUpdated('201007090000Z')
if mibBuilder.loadTexts: juniperMIB.setOrganization('Juniper Networks, Inc.')
if mibBuilder.loadTexts: juniperMIB.setContactInfo('        Juniper Technical Assistance Center\n\t\t     Juniper Networks, Inc.\n\t\t     1194 N. Mathilda Avenue\n\t\t     Sunnyvale, CA 94089\n\t\t     E-mail: support@juniper.net')
if mibBuilder.loadTexts: juniperMIB.setDescription('The Structure of Management Information for Juniper Networks.')
jnxProducts = ObjectIdentity((1, 3, 6, 1, 4, 1, 2636, 1))
if mibBuilder.loadTexts: jnxProducts.setDescription("The root of Juniper's Product OIDs.")
jnxMediaFlow = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 1, 2))
jnxJunosSpace = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 1, 3))
jnxReservedProducts3 = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 1, 4))
jnxReservedProducts4 = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 1, 5))
jnxReservedProducts5 = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 1, 6))
jnxSDKApplicationsRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 1, 7))
jnxJAB = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 1, 8))
jnxStrm = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 1, 9))
jnxServices = ObjectIdentity((1, 3, 6, 1, 4, 1, 2636, 2))
if mibBuilder.loadTexts: jnxServices.setDescription("The root of Juniper's Services OIDs.")
jnxMibs = ObjectIdentity((1, 3, 6, 1, 4, 1, 2636, 3))
if mibBuilder.loadTexts: jnxMibs.setDescription("The root of Juniper's MIB objects.")
jnxJsMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 39))
jnxExMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 40))
jnxWxMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 41))
jnxDcfMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 42))
jnxReservedMibs5 = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 43))
jnxPfeMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 44))
jnxBfdMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 45))
jnxXstpMibs = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 46))
jnxUtilMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 47))
jnxl2aldMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 48))
jnxL2tpMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 49))
jnxRpmMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 50))
jnxUserAAAMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 51))
jnxIpSecMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 52))
jnxL2cpMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 53))
jnxPwTdmMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 54))
jnxPwTCMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 55))
jnxOtnMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 56))
jnxPsuMIBRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 58))
jnxSvcsMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 59))
jnxDomMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 60))
jnxJdhcpMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 61))
jnxJdhcpv6MibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 62))
jnxLicenseMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 63))
jnxSubscriberMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 64))
jnxMagMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 65))
jnxMobileGatewayMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 66))
jnxPppoeMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 67))
jnxPppMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 68))
jnxJVAEMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 69))
jnxIfOtnMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 70))
jnxOpticsMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 71))
jnxAlarmExtMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 72))
jnxoptIfMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 73))
jnxFruMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 74))
jnxTimingNotfnsMIBRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 75))
jnxSnmpSetMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 76))
jnxTraps = ObjectIdentity((1, 3, 6, 1, 4, 1, 2636, 4))
if mibBuilder.loadTexts: jnxTraps.setDescription("The root of Juniper's Trap OIDs.")
jnxChassisTraps = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 1))
jnxChassisOKTraps = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 2))
jnxRmonTraps = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 3))
jnxLdpTraps = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 4))
jnxCmNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 5))
jnxSonetNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 6))
jnxPMonNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 7))
jnxCollectorNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 8))
jnxPingNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 9))
jnxSpNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 10))
jnxDfcNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 11))
jnxSyslogNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 12))
jnxEventNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 13))
jnxVccpNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 14))
jnxOtnNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 15))
jnxSAIDPNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 16))
jnxCosNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 17))
jnxDomNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 18))
jnxFabricChassisTraps = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 19))
jnxFabricChassisOKTraps = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 20))
jnxIfOtnNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 21))
jnxOpticsNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 22))
jnxFruTraps = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 23))
jnxSnmpSetTraps = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 4, 24))
jnxExperiment = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 5))
jnxNsm = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 6))
jnxCA = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 7))
jnxAAA = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 8))
jnxAdvancedInsightMgr = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 9))
jnxBxMibRoot = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 10))
mibBuilder.exportSymbols("JUNIPER-SMI", jnxSonetNotifications=jnxSonetNotifications, jnxCosNotifications=jnxCosNotifications, juniperMIB=juniperMIB, jnxOpticsNotifications=jnxOpticsNotifications, jnxFruTraps=jnxFruTraps, jnxDfcNotifications=jnxDfcNotifications, jnxLicenseMibRoot=jnxLicenseMibRoot, jnxSnmpSetTraps=jnxSnmpSetTraps, jnxL2cpMibRoot=jnxL2cpMibRoot, jnxJdhcpMibRoot=jnxJdhcpMibRoot, jnxOtnNotifications=jnxOtnNotifications, jnxChassisTraps=jnxChassisTraps, jnxAlarmExtMibRoot=jnxAlarmExtMibRoot, jnxoptIfMibRoot=jnxoptIfMibRoot, jnxExMibRoot=jnxExMibRoot, jnxMobileGatewayMibRoot=jnxMobileGatewayMibRoot, jnxJsMibRoot=jnxJsMibRoot, jnxPsuMIBRoot=jnxPsuMIBRoot, jnxBxMibRoot=jnxBxMibRoot, jnxUserAAAMibRoot=jnxUserAAAMibRoot, jnxDcfMibRoot=jnxDcfMibRoot, jnxUtilMibRoot=jnxUtilMibRoot, jnxSyslogNotifications=jnxSyslogNotifications, jnxJdhcpv6MibRoot=jnxJdhcpv6MibRoot, jnxJVAEMibRoot=jnxJVAEMibRoot, jnxVccpNotifications=jnxVccpNotifications, jnxSnmpSetMibRoot=jnxSnmpSetMibRoot, jnxReservedProducts5=jnxReservedProducts5, jnxServices=jnxServices, jnxMibs=jnxMibs, jnxl2aldMibRoot=jnxl2aldMibRoot, jnxCollectorNotifications=jnxCollectorNotifications, jnxSAIDPNotifications=jnxSAIDPNotifications, jnxPppoeMibRoot=jnxPppoeMibRoot, jnxRpmMibRoot=jnxRpmMibRoot, jnxL2tpMibRoot=jnxL2tpMibRoot, jnxJunosSpace=jnxJunosSpace, jnxBfdMibRoot=jnxBfdMibRoot, jnxEventNotifications=jnxEventNotifications, jnxReservedProducts3=jnxReservedProducts3, jnxFabricChassisTraps=jnxFabricChassisTraps, jnxIfOtnNotifications=jnxIfOtnNotifications, jnxWxMibRoot=jnxWxMibRoot, jnxSvcsMibRoot=jnxSvcsMibRoot, jnxReservedMibs5=jnxReservedMibs5, jnxOtnMibRoot=jnxOtnMibRoot, jnxMagMibRoot=jnxMagMibRoot, jnxCmNotifications=jnxCmNotifications, jnxPMonNotifications=jnxPMonNotifications, jnxPingNotifications=jnxPingNotifications, jnxExperiment=jnxExperiment, jnxXstpMibs=jnxXstpMibs, jnxPppMibRoot=jnxPppMibRoot, jnxAAA=jnxAAA, jnxPwTdmMibRoot=jnxPwTdmMibRoot, jnxNsm=jnxNsm, jnxFruMibRoot=jnxFruMibRoot, jnxProducts=jnxProducts, jnxFabricChassisOKTraps=jnxFabricChassisOKTraps, jnxIfOtnMibRoot=jnxIfOtnMibRoot, jnxLdpTraps=jnxLdpTraps, jnxTimingNotfnsMIBRoot=jnxTimingNotfnsMIBRoot, jnxSDKApplicationsRoot=jnxSDKApplicationsRoot, jnxPwTCMibRoot=jnxPwTCMibRoot, jnxAdvancedInsightMgr=jnxAdvancedInsightMgr, jnxMediaFlow=jnxMediaFlow, jnxChassisOKTraps=jnxChassisOKTraps, jnxOpticsMibRoot=jnxOpticsMibRoot, jnxRmonTraps=jnxRmonTraps, jnxDomNotifications=jnxDomNotifications, jnxPfeMibRoot=jnxPfeMibRoot, PYSNMP_MODULE_ID=juniperMIB, jnxTraps=jnxTraps, jnxCA=jnxCA, jnxSpNotifications=jnxSpNotifications, jnxDomMibRoot=jnxDomMibRoot, jnxStrm=jnxStrm, jnxJAB=jnxJAB, jnxIpSecMibRoot=jnxIpSecMibRoot, jnxSubscriberMibRoot=jnxSubscriberMibRoot, jnxReservedProducts4=jnxReservedProducts4)



#
# PySNMP MIB module AGENTX-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/AGENTX-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:04:18 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ValueRangeConstraint, ValueSizeConstraint, ConstraintsUnion, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ValueRangeConstraint", "ValueSizeConstraint", "ConstraintsUnion", "ConstraintsIntersection")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( IpAddress, Bits, Unsigned32, Counter32, NotificationType, MibIdentifier, Gauge32, ModuleIdentity, TimeTicks, Counter64, MibScalar, MibTable, MibTableRow, MibTableColumn, iso, Integer32, ObjectIdentity, mib_2, ) = mibBuilder.importSymbols("SNMPv2-SMI", "IpAddress", "Bits", "Unsigned32", "Counter32", "NotificationType", "MibIdentifier", "Gauge32", "ModuleIdentity", "TimeTicks", "Counter64", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "iso", "Integer32", "ObjectIdentity", "mib-2")
( TextualConvention, TimeStamp, TruthValue, TDomain, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "TimeStamp", "TruthValue", "TDomain", "DisplayString")
agentxMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 74)).setRevisions(("2000-01-10 00:00",))
if mibBuilder.loadTexts: agentxMIB.setLastUpdated('200001100000Z')
if mibBuilder.loadTexts: agentxMIB.setOrganization('AgentX Working Group')
if mibBuilder.loadTexts: agentxMIB.setContactInfo('WG-email:   agentx@dorothy.bmc.com\n               Subscribe:  agentx-request@dorothy.bmc.com\n               WG-email Archive:  ftp://ftp.peer.com/pub/agentx/archives\n               FTP repository:  ftp://ftp.peer.com/pub/agentx\n               http://www.ietf.org/html.charters/agentx-charter.html\n\n               Chair:      Bob Natale\n                           ACE*COMM Corporation\n               Email:      bnatale@acecomm.com\n\n               WG editor:  Mark Ellison\n                           Ellison Software Consulting, Inc.\n               Email:      ellison@world.std.com\n\n               Co-author:  Lauren Heintz\n                           Cisco Systems,\n               EMail:      lheintz@cisco.com\n\n               Co-author:  Smitha Gudur\n                           Independent Consultant\n               Email:      sgudur@hotmail.com\n\n              ')
if mibBuilder.loadTexts: agentxMIB.setDescription('This is the MIB module for the SNMP Agent Extensibility\n     Protocol (AgentX).  This MIB module will be implemented by\n     the master agent.\n    ')
class AgentxTAddress(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,255)

agentxObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 74, 1))
agentxGeneral = MibIdentifier((1, 3, 6, 1, 2, 1, 74, 1, 1))
agentxConnection = MibIdentifier((1, 3, 6, 1, 2, 1, 74, 1, 2))
agentxSession = MibIdentifier((1, 3, 6, 1, 2, 1, 74, 1, 3))
agentxRegistration = MibIdentifier((1, 3, 6, 1, 2, 1, 74, 1, 4))
agentxDefaultTimeout = MibScalar((1, 3, 6, 1, 2, 1, 74, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255)).clone(5)).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxDefaultTimeout.setDescription('The default length of time, in seconds, that the master\n      agent should allow to elapse after dispatching a message\n      to a session before it regards the subagent as not\n      responding.  This is a system-wide value that may\n      override the timeout value associated with a particular\n      session (agentxSessionTimeout) or a particular registered\n      MIB region (agentxRegTimeout).  If the associated value of\n      agentxSessionTimeout and agentxRegTimeout are zero, or\n      impractical in accordance with implementation-specific\n      procedure of the master agent, the value represented by\n      this object will be the effective timeout value for the\n      master agent to await a response to a dispatch from a\n      given subagent.\n     ')
agentxMasterAgentXVer = MibScalar((1, 3, 6, 1, 2, 1, 74, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxMasterAgentXVer.setDescription('The AgentX protocol version supported by this master agent.\n      The current protocol version is 1.  Note that the master agent\n      must also allow interaction with earlier version subagents.\n     ')
agentxConnTableLastChange = MibScalar((1, 3, 6, 1, 2, 1, 74, 1, 2, 1), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxConnTableLastChange.setDescription('The value of sysUpTime when the last row creation or deletion\n      occurred in the agentxConnectionTable.\n     ')
agentxConnectionTable = MibTable((1, 3, 6, 1, 2, 1, 74, 1, 2, 2), )
if mibBuilder.loadTexts: agentxConnectionTable.setDescription('The agentxConnectionTable tracks all current AgentX transport\n      connections.  There may be zero, one, or more AgentX sessions\n      carried on a given AgentX connection.\n     ')
agentxConnectionEntry = MibTableRow((1, 3, 6, 1, 2, 1, 74, 1, 2, 2, 1), ).setIndexNames((0, "AGENTX-MIB", "agentxConnIndex"))
if mibBuilder.loadTexts: agentxConnectionEntry.setDescription('An agentxConnectionEntry contains information describing a\n      single AgentX transport connection.  A connection may be\n      used to support zero or more AgentX sessions.  An entry is\n      created when a new transport connection is established,\n      and is destroyed when the transport connection is terminated.\n     ')
agentxConnIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 2, 2, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: agentxConnIndex.setDescription('agentxConnIndex contains the value that uniquely identifies\n      an open transport connection used by this master agent\n      to provide AgentX service.  Values of this index should\n      not be re-used.  The value assigned to a given transport\n      connection is constant for the lifetime of that connection.\n     ')
agentxConnOpenTime = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 2, 2, 1, 2), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxConnOpenTime.setDescription('The value of sysUpTime when this connection was established\n      and, therefore, its value when this entry was added to the table.\n     ')
agentxConnTransportDomain = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 2, 2, 1, 3), TDomain()).setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxConnTransportDomain.setDescription('The transport protocol in use for this connection to the\n      subagent.\n     ')
agentxConnTransportAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 2, 2, 1, 4), AgentxTAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxConnTransportAddress.setDescription('The transport address of the remote (subagent) end of this\n      connection to the master agent.  This object may be zero-length\n      for unix-domain sockets (and possibly other types of transport\n      addresses) since the subagent need not bind a filename to its\n      local socket.\n     ')
agentxSessionTableLastChange = MibScalar((1, 3, 6, 1, 2, 1, 74, 1, 3, 1), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxSessionTableLastChange.setDescription('The value of sysUpTime when the last row creation or deletion\n      occurred in the agentxSessionTable.\n     ')
agentxSessionTable = MibTable((1, 3, 6, 1, 2, 1, 74, 1, 3, 2), )
if mibBuilder.loadTexts: agentxSessionTable.setDescription('A table of AgentX subagent sessions currently in effect.\n     ')
agentxSessionEntry = MibTableRow((1, 3, 6, 1, 2, 1, 74, 1, 3, 2, 1), ).setIndexNames((0, "AGENTX-MIB", "agentxConnIndex"), (0, "AGENTX-MIB", "agentxSessionIndex"))
if mibBuilder.loadTexts: agentxSessionEntry.setDescription('Information about a single open session between the AgentX\n      master agent and a subagent is contained in this entry.  An\n      entry is created when a new session is successfully established\n      and is destroyed either when the subagent transport connection\n      has terminated or when the subagent session is closed.\n     ')
agentxSessionIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 3, 2, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,4294967295)))
if mibBuilder.loadTexts: agentxSessionIndex.setDescription("A unique index for the subagent session.  It is the same as\n      h.sessionID defined in the agentx header.  Note that if\n      a subagent's session with the master agent is closed for\n      any reason its index should not be re-used.\n      A value of zero(0) is specifically allowed in order\n      to be compatible with the definition of h.sessionId.\n     ")
agentxSessionObjectID = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 3, 2, 1, 2), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxSessionObjectID.setDescription("This is taken from the o.id field of the agentx-Open-PDU.\n      This attribute will report a value of '0.0' for subagents\n      not supporting the notion of an AgentX session object\n      identifier.\n     ")
agentxSessionDescr = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 3, 2, 1, 3), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxSessionDescr.setDescription('A textual description of the session.  This is analogous to\n      sysDescr defined in the SNMPv2-MIB in RFC 1907 [19] and is\n      taken from the o.descr field of the agentx-Open-PDU.\n      This attribute will report a zero-length string value for\n      subagents not supporting the notion of a session description.\n     ')
agentxSessionAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 3, 2, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("up", 1), ("down", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: agentxSessionAdminStatus.setDescription("The administrative (desired) status of the session.  Setting\n      the value to 'down(2)' closes the subagent session (with c.reason\n      set to 'reasonByManager').\n     ")
agentxSessionOpenTime = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 3, 2, 1, 5), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxSessionOpenTime.setDescription('The value of sysUpTime when this session was opened and,\n      therefore, its value when this entry was added to the table.\n     ')
agentxSessionAgentXVer = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 3, 2, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxSessionAgentXVer.setDescription('The version of the AgentX protocol supported by the\n      session.  This must be less than or equal to the value of\n      agentxMasterAgentXVer.\n     ')
agentxSessionTimeout = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 3, 2, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxSessionTimeout.setDescription("The length of time, in seconds, that a master agent should\n      allow to elapse after dispatching a message to this session\n      before it regards the subagent as not responding.  This value\n      is taken from the o.timeout field of the agentx-Open-PDU.\n      This is a session-specific value that may be overridden by\n      values associated with the specific registered MIB regions\n      (see agentxRegTimeout). A value of zero(0) indicates that\n      the master agent's default timeout value should be used\n      (see agentxDefaultTimeout).\n     ")
agentxRegistrationTableLastChange = MibScalar((1, 3, 6, 1, 2, 1, 74, 1, 4, 1), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxRegistrationTableLastChange.setDescription('The value of sysUpTime when the last row creation or deletion\n      occurred in the agentxRegistrationTable.\n     ')
agentxRegistrationTable = MibTable((1, 3, 6, 1, 2, 1, 74, 1, 4, 2), )
if mibBuilder.loadTexts: agentxRegistrationTable.setDescription('A table of registered regions.\n     ')
agentxRegistrationEntry = MibTableRow((1, 3, 6, 1, 2, 1, 74, 1, 4, 2, 1), ).setIndexNames((0, "AGENTX-MIB", "agentxConnIndex"), (0, "AGENTX-MIB", "agentxSessionIndex"), (0, "AGENTX-MIB", "agentxRegIndex"))
if mibBuilder.loadTexts: agentxRegistrationEntry.setDescription('Contains information for a single registered region.  An\n      entry is created when a session  successfully registers a\n      region and is destroyed for any of three reasons: this region\n      is unregistered by the session, the session is closed,\n      or the subagent connection is closed.\n     ')
agentxRegIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 4, 2, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: agentxRegIndex.setDescription('agentxRegIndex uniquely identifies a registration entry.\n      This value is constant for the lifetime of an entry.\n     ')
agentxRegContext = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 4, 2, 1, 2), OctetString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxRegContext.setDescription('The context in which the session supports the objects in this\n      region.  A zero-length context indicates the default context.\n     ')
agentxRegStart = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 4, 2, 1, 3), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxRegStart.setDescription('The starting OBJECT IDENTIFIER of this registration entry.  The\n      session identified by agentxSessionIndex implements objects\n      starting at this value (inclusive).  Note that this value could\n      identify an object type, an object instance, or a partial object\n      instance.\n     ')
agentxRegRangeSubId = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 4, 2, 1, 4), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxRegRangeSubId.setDescription("agentxRegRangeSubId is used to specify the range.  This is\n      taken from r.region_subid in the registration PDU.  If the value\n      of this object is zero, no range is specified.  If it is non-zero,\n      it identifies the `nth' sub-identifier in r.region for which\n      this entry's agentxRegUpperBound value is substituted in the\n      OID for purposes of defining the region's upper bound.\n     ")
agentxRegUpperBound = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 4, 2, 1, 5), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxRegUpperBound.setDescription('agentxRegUpperBound represents the upper-bound sub-identifier in\n     a registration.  This is taken from the r.upper_bound in the\n     registration PDU.  If agentxRegRangeSubid (r.region_subid) is\n     zero, this value is also zero and is not used to define an upper\n     bound for this registration.\n    ')
agentxRegPriority = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 4, 2, 1, 6), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxRegPriority.setDescription('The registration priority.  Lower values have higher priority.\n      This value is taken from r.priority in the register PDU.\n      Sessions should use the value of 127 for r.priority if a\n      default value is desired.\n     ')
agentxRegTimeout = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 4, 2, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxRegTimeout.setDescription('The timeout value, in seconds, for responses to\n      requests associated with this registered MIB region.\n      A value of zero(0) indicates the default value (indicated\n      by by agentxSessionTimeout or agentxDefaultTimeout) is to\n      be used.  This value is taken from the r.timeout field of\n      the agentx-Register-PDU.\n     ')
agentxRegInstance = MibTableColumn((1, 3, 6, 1, 2, 1, 74, 1, 4, 2, 1, 8), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: agentxRegInstance.setDescription("The value of agentxRegInstance is `true' for\n      registrations for which the INSTANCE_REGISTRATION\n      was set, and is `false' for all other registrations.\n     ")
agentxConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 74, 2))
agentxMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 74, 2, 1))
agentxMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 74, 2, 2))
agentxMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 74, 2, 2, 1)).setObjects(*(("AGENTX-MIB", "agentxMIBGroup"),))
if mibBuilder.loadTexts: agentxMIBCompliance.setDescription('The compliance statement for SNMP entities that implement the\n      AgentX protocol.  Note that a compliant agent can implement all\n      objects in this MIB module as read-only.\n     ')
agentxMIBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 74, 2, 1, 1)).setObjects(*(("AGENTX-MIB", "agentxDefaultTimeout"), ("AGENTX-MIB", "agentxMasterAgentXVer"), ("AGENTX-MIB", "agentxConnTableLastChange"), ("AGENTX-MIB", "agentxConnOpenTime"), ("AGENTX-MIB", "agentxConnTransportDomain"), ("AGENTX-MIB", "agentxConnTransportAddress"), ("AGENTX-MIB", "agentxSessionTableLastChange"), ("AGENTX-MIB", "agentxSessionTimeout"), ("AGENTX-MIB", "agentxSessionObjectID"), ("AGENTX-MIB", "agentxSessionDescr"), ("AGENTX-MIB", "agentxSessionAdminStatus"), ("AGENTX-MIB", "agentxSessionOpenTime"), ("AGENTX-MIB", "agentxSessionAgentXVer"), ("AGENTX-MIB", "agentxRegistrationTableLastChange"), ("AGENTX-MIB", "agentxRegContext"), ("AGENTX-MIB", "agentxRegStart"), ("AGENTX-MIB", "agentxRegRangeSubId"), ("AGENTX-MIB", "agentxRegUpperBound"), ("AGENTX-MIB", "agentxRegPriority"), ("AGENTX-MIB", "agentxRegTimeout"), ("AGENTX-MIB", "agentxRegInstance"),))
if mibBuilder.loadTexts: agentxMIBGroup.setDescription('All accessible objects in the AgentX MIB.\n     ')
mibBuilder.exportSymbols("AGENTX-MIB", agentxRegUpperBound=agentxRegUpperBound, agentxRegStart=agentxRegStart, agentxRegistrationTableLastChange=agentxRegistrationTableLastChange, agentxConnOpenTime=agentxConnOpenTime, agentxSessionAdminStatus=agentxSessionAdminStatus, agentxConformance=agentxConformance, agentxMIBGroup=agentxMIBGroup, agentxSessionObjectID=agentxSessionObjectID, agentxConnectionEntry=agentxConnectionEntry, PYSNMP_MODULE_ID=agentxMIB, agentxRegistrationTable=agentxRegistrationTable, agentxConnTransportDomain=agentxConnTransportDomain, agentxRegInstance=agentxRegInstance, agentxRegTimeout=agentxRegTimeout, agentxRegPriority=agentxRegPriority, agentxSessionTableLastChange=agentxSessionTableLastChange, agentxConnectionTable=agentxConnectionTable, agentxRegContext=agentxRegContext, agentxConnTransportAddress=agentxConnTransportAddress, agentxMIBCompliance=agentxMIBCompliance, agentxObjects=agentxObjects, agentxConnIndex=agentxConnIndex, agentxSessionEntry=agentxSessionEntry, agentxMIB=agentxMIB, agentxRegRangeSubId=agentxRegRangeSubId, agentxConnTableLastChange=agentxConnTableLastChange, agentxSessionTimeout=agentxSessionTimeout, agentxMasterAgentXVer=agentxMasterAgentXVer, agentxSessionOpenTime=agentxSessionOpenTime, agentxRegistration=agentxRegistration, agentxSessionDescr=agentxSessionDescr, agentxSessionIndex=agentxSessionIndex, agentxMIBCompliances=agentxMIBCompliances, agentxGeneral=agentxGeneral, agentxSessionAgentXVer=agentxSessionAgentXVer, agentxRegistrationEntry=agentxRegistrationEntry, agentxSessionTable=agentxSessionTable, agentxRegIndex=agentxRegIndex, AgentxTAddress=AgentxTAddress, agentxSession=agentxSession, agentxConnection=agentxConnection, agentxMIBGroups=agentxMIBGroups, agentxDefaultTimeout=agentxDefaultTimeout)
